@@ -4,11 +4,11 @@ from pyxcp.asam import types
 
 
 def testEncodeUint32_0():
-    assert types.A_Uint32("<").encode(3415750566) == b'\xa67\x98\xcb'
+    assert types.A_Uint32("<").encode(3415750566) == b"\xa67\x98\xcb"
 
 
 def testDecodeUint32_0():
-    assert types.A_Uint32("<").decode((0xa6, 0x37, 0x98, 0xcb)) == 3415750566
+    assert types.A_Uint32("<").decode((0xA6, 0x37, 0x98, 0xCB)) == 3415750566
 
 
 def testLittleEndian():
@@ -21,4 +21,4 @@ def testBigEndian():
 
 def testInvalidByteOrderRaisesTypeError():
     with pytest.raises(ValueError):
-        types.AsamBaseType('#')
+        types.AsamBaseType("#")
