@@ -27,10 +27,10 @@ import abc
 from collections import deque
 import threading
 from datetime import datetime
-from time import time, sleep, perf_counter
+from time import time, sleep, get_clock_info
 
 from ..logger import Logger
-from ..utils import flatten, hexDump
+from ..utils import flatten, hexDump, time_perfcounter_correlation
 
 import pyxcp.types as types
 from pyxcp.config import Configuration
@@ -43,8 +43,7 @@ class Empty(Exception):
 
 
 def get(q, timeout):
-    """Get an item from a deque considering a timeout condition.
-    """
+    """Get an item from a deque considering a timeout condition."""
     start = time()
     while not q:
         if time() - start > timeout:
@@ -69,8 +68,9 @@ class BaseTransport(metaclass=abc.ABCMeta):
 
     PARAMETER_MAP = {
         #                         Type    Req'd   Default
-        "CREATE_DAQ_TIMESTAMPS": (bool,   False,  False),
-        "LOGLEVEL":              (str,    False,  "WARN"),
+        "CREATE_DAQ_TIMESTAMPS": (bool, False, False),
+        "LOGLEVEL": (str, False, "WARN"),
+        "TIMEOUT": (float, False, 2.0),
     }
 
     def __init__(self, config=None):
@@ -78,12 +78,16 @@ class BaseTransport(metaclass=abc.ABCMeta):
         self.config = Configuration(BaseTransport.PARAMETER_MAP or {}, config or {})
         self.closeEvent = threading.Event()
         loglevel = self.config.get("LOGLEVEL")
+        self._debug = loglevel == "DEBUG"
+
         self.logger = Logger("transport.Base")
         self.logger.setLevel(loglevel)
         self.counterSend = 0
         self.counterReceived = -1
         create_daq_timestamps = self.config.get("CREATE_DAQ_TIMESTAMPS")
         self.create_daq_timestamps = False if create_daq_timestamps is None else create_daq_timestamps
+        timeout = self.config.get("TIMEOUT")
+        self.timeout = 2.0 if timeout is None else timeout
         self.timing = Timing()
         self.resQueue = deque()
         self.daqQueue = deque()
@@ -96,8 +100,19 @@ class BaseTransport(metaclass=abc.ABCMeta):
         )
 
         self.first_daq_timestamp = None
+        if get_clock_info("time").resolution > 1e-5:
+            ts, pc = time_perfcounter_correlation()
+            self.timestamp_origin = ts
+            self.datetime_origin = datetime.fromtimestamp(ts)
+            self.perf_counter_origin = pc
+        else:
+            self.timestamp_origin = time()
+            self.datetime_origin = datetime.fromtimestamp(self.timestamp_origin)
+
+            # we will later use this to know if the current platform has a high
+            # resolution time.time implementation
+            self.perf_counter_origin = -1
 
-        self.datetime_origin, self.timestamp_origin = datetime.now(), time()
         self.pre_send_timestamp = time()
         self.post_send_timestamp = time()
         self.recv_timestamp = time()
@@ -107,13 +122,11 @@ class BaseTransport(metaclass=abc.ABCMeta):
         self.closeConnection()
 
     def loadConfig(self, config):
-        """Load configuration data.
-        """
+        """Load configuration data."""
         self.config = Configuration(self.PARAMETER_MAP or {}, config or {})
 
     def close(self):
-        """Close the transport-layer connection and event-loop.
-        """
+        """Close the transport-layer connection and event-loop."""
         self.finishListener()
         if self.listener.is_alive():
             self.listener.join()
@@ -136,18 +149,18 @@ class BaseTransport(metaclass=abc.ABCMeta):
         self.send(frame)
 
         try:
-            xcpPDU = get(self.resQueue, timeout=2.0)
+            xcpPDU = get(self.resQueue, timeout=self.timeout)
         except Empty:
-            raise types.XcpTimeoutError("Response timed out.") from None
+            raise types.XcpTimeoutError("Response timed out (timeout={}s)".format(self.timeout)) from None
 
         self.timing.stop()
 
         pid = types.Response.parse(xcpPDU).type
-        if pid == 'ERR' and cmd.name != 'SYNCH':
+        if pid == "ERR" and cmd.name != "SYNCH":
             err = types.XcpError.parse(xcpPDU[1:])
             raise types.XcpResponseError(err)
         else:
-            pass    # Und nu??
+            pass  # Und nu??
         return xcpPDU[1:]
 
     def block_request(self, cmd, *data):
@@ -162,7 +175,7 @@ class BaseTransport(metaclass=abc.ABCMeta):
         if self.resQueue:
             xcpPDU = self.resQueue.popleft()
             pid = types.Response.parse(xcpPDU).type
-            if pid == 'ERR' and cmd.name != 'SYNCH':
+            if pid == "ERR" and cmd.name != "SYNCH":
                 err = types.XcpError.parse(xcpPDU[1:])
                 raise types.XcpResponseError(err)
 
@@ -173,14 +186,16 @@ class BaseTransport(metaclass=abc.ABCMeta):
         """
         Prepares a request to be sent
         """
-        self.logger.debug(cmd.name)
+        if self._debug:
+            self.logger.debug(cmd.name)
         self.parent._setService(cmd)
         cmdlen = cmd.bit_length() // 8  # calculate bytes needed for cmd
         header = self.HEADER.pack(cmdlen + len(data), self.counterSend)
-        self.counterSend = (self.counterSend + 1) & 0xffff
+        self.counterSend = (self.counterSend + 1) & 0xFFFF
 
-        frame = header + bytes(flatten(cmd.to_bytes(cmdlen, 'big'), data))
-        self.logger.debug("-> {}".format(hexDump(frame)))
+        frame = header + bytes(flatten(cmd.to_bytes(cmdlen, "big"), data))
+        if self._debug:
+            self.logger.debug("-> {}".format(hexDump(frame)))
         return frame
 
     def block_receive(self, length_required: int) -> bytes:
@@ -202,8 +217,8 @@ class BaseTransport(metaclass=abc.ABCMeta):
         ------
         :class:`pyxcp.types.XcpTimeoutError`
         """
-        TIMEOUT = 1.0   # TODO: parameter.
-        block_response = b''
+        TIMEOUT = 1.0  # TODO: parameter.
+        block_response = b""
         start = time()
         while len(block_response) < length_required:
             if len(self.resQueue):
@@ -233,37 +248,48 @@ class BaseTransport(metaclass=abc.ABCMeta):
     def processResponse(self, response, length, counter, recv_timestamp=None):
         if counter == self.counterReceived:
             self.logger.warn("Duplicate message counter {} received from the XCP slave".format(counter))
-            self.logger.debug(
-                "<- L{} C{} {}".format(
-                    length,
-                    counter,
-                    hexDump(response[:20]),
+            if self._debug:
+                self.logger.debug(
+                    "<- L{} C{} {}".format(
+                        length,
+                        counter,
+                        hexDump(response[:512]),
+                    )
                 )
-            )
             return
 
         self.counterReceived = counter
 
         pid = response[0]
         if pid >= 0xFC:
-            self.logger.debug(
-                "<- L{} C{} {}".format(
-                    length,
-                    counter,
-                    hexDump(response),
+            if self._debug:
+                self.logger.debug(
+                    "<- L{} C{} {}".format(
+                        length,
+                        counter,
+                        hexDump(response),
+                    )
                 )
-            )
-            if pid >= 0xfe:
+            if pid >= 0xFE:
                 # self.resQueue.put(response)
                 self.resQueue.append(response)
                 self.recv_timestamp = recv_timestamp
-            elif pid == 0xfd:
+            elif pid == 0xFD:
                 # self.evQueue.put(response)
                 self.evQueue.append(response)
-            elif pid == 0xfc:
+            elif pid == 0xFC:
                 # self.servQueue.put(response)
                 self.servQueue.append(response)
+                print("SRV", response.tobytes())
         else:
+            if self._debug:
+                self.logger.debug(
+                    "<- L{} C{} ODT_Data[0:8] {}".format(
+                        length,
+                        counter,
+                        hexDump(response[:8]),
+                    )
+                )
             if self.first_daq_timestamp is None:
                 self.first_daq_timestamp = recv_timestamp
             if self.create_daq_timestamps:
@@ -271,7 +297,9 @@ class BaseTransport(metaclass=abc.ABCMeta):
             else:
                 timestamp = 0.0
             element = (response, counter, length, timestamp)
-            self.daqQueue.append(element)
+            if self.cro_callback:
+                self.cro_callback("DAQ", *element)
+            #self.daqQueue.append(element)
 
 
 def createTransport(name, *args, **kws):
@@ -286,9 +314,8 @@ def createTransport(name, *args, **kws):
     if name in transports:
         transportClass = transports[name]
     else:
-        raise ValueError("'{}' is an invalid transport -- please choose one of [{}].".format(name,
-                ' | '.join(transports.keys())
-            )
+        raise ValueError(
+            "'{}' is an invalid transport -- please choose one of [{}].".format(name, " | ".join(transports.keys()))
         )
     return transportClass(*args, **kws)
 
